=== modified file 'Makefile.am'
--- Makefile.am	2010-10-14 01:10:46 +0000
+++ Makefile.am	2010-10-19 00:32:30 +0000
@@ -163,14 +163,14 @@
 
 install-exec-hook:
 	cd $(DESTDIR)$(sbindir) && \
-	mv -f drizzled$(EXEEXT) drizzled$(PACKAGE_VERSION)$(EXEEXT) && \
-	$(LN_S) drizzled$(PACKAGE_VERSION)$(EXEEXT) drizzled$(EXEEXT)
+	mv -f drizzled$(EXEEXT) drizzled7$(EXEEXT) && \
+	$(LN_S) drizzled7$(EXEEXT) drizzled$(EXEEXT)
 
 install-data-hook:
 	cd $(DESTDIR)$(man8dir) && \
-	mv -f drizzled.8 drizzled$(PACKAGE_VERSION).8 && \
-	$(LN_S) drizzled$(PACKAGE_VERSION).8 drizzled.8
+	mv -f drizzled.8 drizzled7.8 && \
+	$(LN_S) drizzled7.8 drizzled.8
 
 uninstall-hook:
-	rm $(DESTDIR)$(man8dir)/drizzled$(PACKAGE_VERSION).8
-	rm $(DESTDIR)$(sbindir)/drizzled$(PACKAGE_VERSION)$(EXEEXT)
+	rm $(DESTDIR)$(man8dir)/drizzled7.8
+	rm $(DESTDIR)$(sbindir)/drizzled7$(EXEEXT)

=== modified file 'docs/include.am'
--- docs/include.am	2010-10-11 06:27:10 +0000
+++ docs/include.am	2010-10-19 00:32:30 +0000
@@ -9,7 +9,8 @@
 	     docs/Doxyfile \
 	     docs/drizzled_header.html \
 	     ${top_srcdir}/docs/*.rst \
-	     ${top_srcdir}/docs/clients/*.rst
+	     ${top_srcdir}/docs/clients/*.rst \
+	     ${top_srcdir}/docs/libdrizzle/*.rst
 
 # Makefile for Sphinx documentation
 #

=== modified file 'drizzled/lock.cc'
--- drizzled/lock.cc	2010-10-08 16:11:47 +0000
+++ drizzled/lock.cc	2010-10-19 04:37:10 +0000
@@ -34,7 +34,7 @@
       This is followed by a call to thr_multi_lock() for all tables.
 
   - When statement is done, we call mysql_unlock_tables().
-    This will call thr_multi_unlock() followed by
+    This will call DrizzleLock::unlock() followed by
     table_handler->external_lock(session, F_UNLCK) for each table.
 
   - Note that mysql_unlock_tables() may be called several times as
@@ -164,20 +164,19 @@
 static void reset_lock_data_and_free(DrizzleLock **mysql_lock)
 {
   DrizzleLock *sql_lock= *mysql_lock;
-  THR_LOCK_DATA **ldata, **ldata_end;
-
-  /* Clear the lock type of all lock data to avoid reusage. */
-  for (ldata= sql_lock->locks, ldata_end= ldata + sql_lock->lock_count;
-       ldata < ldata_end;
-       ldata++)
-  {
-    /* Reset lock type. */
-    (*ldata)->type= TL_UNLOCK;
-  }
-  free((unsigned char*) sql_lock);
+  sql_lock->reset();
+  delete sql_lock;
   *mysql_lock= 0;
 }
 
+void DrizzleLock::reset(void)
+{
+  for (std::vector<THR_LOCK_DATA *>::iterator iter= locks.begin(); iter != locks.end(); iter++)
+  {
+    (*iter)->type= TL_UNLOCK;
+  }
+}
+
 
 DrizzleLock *mysql_lock_tables(Session *session, Table **tables, uint32_t count,
                                 uint32_t flags, bool *need_reopen)
@@ -247,7 +246,7 @@
      * of the type of lock that Drizzle intends to take on a 
      * specific table.
      */
-    if (sql_lock->table_count && lock_external(session, sql_lock->table,
+    if (sql_lock->table_count && lock_external(session, sql_lock->getTable(),
                                                sql_lock->table_count))
     {
       /* Clear the lock type of all lock data to avoid reusage. */
@@ -256,17 +255,18 @@
     }
     session->set_proc_info("Table lock");
     /* Copy the lock data array. thr_multi_lock() reorders its contens. */
-    memcpy(sql_lock->locks + sql_lock->lock_count, sql_lock->locks,
-           sql_lock->lock_count * sizeof(*sql_lock->locks));
+    memcpy(sql_lock->getLocks() + sql_lock->lock_count,
+           sql_lock->getLocks(),
+           sql_lock->lock_count * sizeof(*sql_lock->getLocks()));
     /* Lock on the copied half of the lock data array. */
-    rc= thr_lock_errno_to_mysql[(int) thr_multi_lock(sql_lock->locks +
+    rc= thr_lock_errno_to_mysql[(int) thr_multi_lock(sql_lock->getLocks() +
                                                      sql_lock->lock_count,
                                                      sql_lock->lock_count,
                                                      session->lock_id)];
     if (rc > 1)                                 /* a timeout or a deadlock */
     {
       if (sql_lock->table_count)
-        unlock_external(session, sql_lock->table, sql_lock->table_count);
+        unlock_external(session, sql_lock->getTable(), sql_lock->table_count);
       reset_lock_data_and_free(&sql_lock);
       my_error(rc, MYF(0));
       break;
@@ -295,10 +295,10 @@
 
     /* going to retry, unlock all tables */
     if (sql_lock->lock_count)
-        thr_multi_unlock(sql_lock->locks, sql_lock->lock_count);
+        sql_lock->unlock(sql_lock->lock_count);
 
     if (sql_lock->table_count)
-      unlock_external(session, sql_lock->table, sql_lock->table_count);
+      unlock_external(session, sql_lock->getTable(), sql_lock->table_count);
 
     /*
       If thr_multi_lock fails it resets lock type for tables, which
@@ -340,9 +340,8 @@
 
 static int lock_external(Session *session, Table **tables, uint32_t count)
 {
-  register uint32_t i;
   int lock_type,error;
-  for (i=1 ; i <= count ; i++, tables++)
+  for (uint32_t i= 1 ; i <= count ; i++, tables++)
   {
     assert((*tables)->reginfo.lock_type >= TL_READ);
     lock_type=F_WRLCK;				/* Lock exclusive */
@@ -375,11 +374,10 @@
 void mysql_unlock_tables(Session *session, DrizzleLock *sql_lock)
 {
   if (sql_lock->lock_count)
-    thr_multi_unlock(sql_lock->locks,sql_lock->lock_count);
+    sql_lock->unlock(sql_lock->lock_count);
   if (sql_lock->table_count)
-    unlock_external(session, sql_lock->table, sql_lock->table_count);
-  free((unsigned char*) sql_lock);
-  return;
+    unlock_external(session, sql_lock->getTable(), sql_lock->table_count);
+  delete sql_lock;
 }
 
 /**
@@ -407,12 +405,12 @@
   uint32_t i,found;
 
   /* Move all write locks first */
-  THR_LOCK_DATA **lock=sql_lock->locks;
+  THR_LOCK_DATA **lock=sql_lock->getLocks();
   for (i=found=0 ; i < sql_lock->lock_count ; i++)
   {
-    if (sql_lock->locks[i]->type >= TL_WRITE_ALLOW_READ)
+    if (sql_lock->getLocks()[i]->type >= TL_WRITE_ALLOW_READ)
     {
-      std::swap(*lock, sql_lock->locks[i]);
+      std::swap(*lock, sql_lock->getLocks()[i]);
       lock++;
       found++;
     }
@@ -420,19 +418,19 @@
   /* unlock the read locked tables */
   if (i != found)
   {
-    thr_multi_unlock(lock,i-found);
+    sql_lock->unlock(i - found);
     sql_lock->lock_count= found;
   }
 
   /* Then do the same for the external locks */
   /* Move all write locked tables first */
-  Table **table=sql_lock->table;
+  Table **table= sql_lock->getTable();
   for (i=found=0 ; i < sql_lock->table_count ; i++)
   {
-    assert(sql_lock->table[i]->lock_position == i);
-    if ((uint32_t) sql_lock->table[i]->reginfo.lock_type >= TL_WRITE_ALLOW_READ)
+    assert(sql_lock->getTable()[i]->lock_position == i);
+    if ((uint32_t) sql_lock->getTable()[i]->reginfo.lock_type >= TL_WRITE_ALLOW_READ)
     {
-      std::swap(*table, sql_lock->table[i]);
+      std::swap(*table, sql_lock->getTable()[i]);
       table++;
       found++;
     }
@@ -444,12 +442,12 @@
     sql_lock->table_count=found;
   }
   /* Fix the lock positions in Table */
-  table= sql_lock->table;
+  table= sql_lock->getTable();
   found= 0;
   for (i= 0; i < sql_lock->table_count; i++)
   {
     Table *tbl= *table;
-    tbl->lock_position= table - sql_lock->table;
+    tbl->lock_position= table - sql_lock->getTable();
     tbl->lock_data_start= found;
     found+= tbl->lock_count;
     table++;
@@ -495,8 +493,8 @@
                              &write_lock_used)))
   {
     for (uint32_t x= 0; x < locked->lock_count; x++)
-      locked->locks[x]->lock->abort_locks();
-    free((unsigned char*) locked);
+      locked->getLocks()[x]->lock->abort_locks();
+    delete locked;
   }
 }
 
@@ -524,17 +522,17 @@
   {
     for (uint32_t i= 0; i < locked->lock_count; i++)
     {
-      if (locked->locks[i]->lock->abort_locks_for_thread(table->in_use->thread_id))
+      if (locked->getLocks()[i]->lock->abort_locks_for_thread(table->in_use->thread_id))
         result= true;
     }
-    free((unsigned char*) locked);
+    delete locked;
   }
   return result;
 }
 
 /** Unlock a set of external. */
 
-static int unlock_external(Session *session, Table **table,uint32_t count)
+static int unlock_external(Session *session, Table **table, uint32_t count)
 {
   int error,error_code;
 
@@ -570,19 +568,18 @@
 static DrizzleLock *get_lock_data(Session *session, Table **table_ptr, uint32_t count,
 				 bool should_lock, Table **write_lock_used)
 {
-  uint32_t tables,lock_count;
+  uint32_t lock_count;
   DrizzleLock *sql_lock;
   THR_LOCK_DATA **locks, **locks_buf, **locks_start;
   Table **to, **table_buf;
 
   *write_lock_used=0;
-  for (uint32_t i= tables= lock_count= 0 ; i < count ; i++)
+  for (uint32_t i= lock_count= 0 ; i < count ; i++)
   {
     Table *t= table_ptr[i];
 
     if (! (t->getEngine()->check_flag(HTON_BIT_SKIP_STORE_LOCK)))
     {
-      tables++;
       lock_count++;
     }
   }
@@ -593,16 +590,13 @@
     update the table values. So the second part of the array is copied
     from the first part immediately before calling thr_multi_lock().
   */
-  if (!(sql_lock= (DrizzleLock*)
-	malloc(sizeof(*sql_lock) +
-               sizeof(THR_LOCK_DATA*) * tables * 2 +
-               sizeof(table_ptr) * lock_count)))
-  {
+  sql_lock= new DrizzleLock(lock_count, lock_count*2);
+
+  if (not sql_lock)
     return NULL;
-  }
-  locks= locks_buf= sql_lock->locks= (THR_LOCK_DATA**) (sql_lock + 1);
-  to= table_buf= sql_lock->table= (Table**) (locks + tables * 2);
-  sql_lock->table_count= lock_count;
+
+  locks= locks_buf= sql_lock->getLocks();
+  to= table_buf= sql_lock->getTable();
 
   for (uint32_t i= 0; i < count ; i++)
   {
@@ -622,7 +616,7 @@
       {
 	my_error(ER_OPEN_AS_READONLY, MYF(0), table->getAlias());
         /* Clear the lock type of the lock data that are stored already. */
-        sql_lock->lock_count= locks - sql_lock->locks;
+        sql_lock->lock_count= locks - sql_lock->getLocks();
         reset_lock_data_and_free(&sql_lock);
 	return NULL;
       }

=== modified file 'drizzled/lock.h'
--- drizzled/lock.h	2010-09-28 00:51:44 +0000
+++ drizzled/lock.h	2010-10-19 04:37:10 +0000
@@ -20,6 +20,7 @@
 #ifndef DRIZZLED_LOCK_H
 #define DRIZZLED_LOCK_H
 
+#include <vector>
 #include "drizzled/thr_lock.h"
 
 namespace drizzled
@@ -28,7 +29,62 @@
 class Session;
 class Table;
 class TableList;
-class DrizzleLock;
+
+class DrizzleLock
+{
+  std::vector<Table *> table;
+  std::vector<THR_LOCK_DATA *> locks;
+public:
+  uint32_t table_count;
+  uint32_t lock_count;
+
+  Table **getTable()
+  {
+    return &table[0];
+  }
+
+  THR_LOCK_DATA **getLocks()
+  {
+    return &locks[0];
+  }
+
+  size_t sizeLock()
+  {
+    return lock_count;
+  }
+
+  size_t sizeTable()
+  {
+    return table_count;
+  }
+
+  void resetLock()
+  {
+    lock_count= 0;
+  }
+
+  void setLock(size_t arg)
+  {
+    lock_count= arg;
+  }
+
+  void setTable(size_t arg)
+  {
+    table_count= arg;
+  }
+
+  void reset(void);
+  void unlock(uint32_t count);
+
+  DrizzleLock(size_t table_count_arg, size_t lock_count_arg) :
+    table_count(table_count_arg),
+    lock_count(lock_count_arg)
+  {
+    table.resize(table_count);
+    locks.resize(lock_count);
+  }
+
+};
 
 DrizzleLock *mysql_lock_tables(Session *session, Table **table, uint32_t count,
                                uint32_t flags, bool *need_reopen);

=== modified file 'drizzled/plugin/event_observer.cc'
--- drizzled/plugin/event_observer.cc	2010-10-14 23:27:38 +0000
+++ drizzled/plugin/event_observer.cc	2010-10-18 18:24:29 +0000
@@ -99,7 +99,7 @@
     {
       for_each(event_observer_lists.begin(),
                event_observer_lists.end(),
-               SafeDeletePtr());
+               DeletePtr());
 			event_observer_lists.clear();
     }
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-10-18 17:22:59 +0000
+++ drizzled/session.cc	2010-10-19 13:38:53 +0000
@@ -1776,29 +1776,28 @@
 
 user_var_entry *Session::getVariable(const std::string  &name, bool create_if_not_exists)
 {
-  user_var_entry *entry= NULL;
   UserVarsRange ppp= user_vars.equal_range(name);
 
   for (UserVars::iterator iter= ppp.first;
-         iter != ppp.second; ++iter)
+       iter != ppp.second; ++iter)
   {
-    entry= (*iter).second;
+    return (*iter).second;
   }
 
-  if ((entry == NULL) && create_if_not_exists)
+  if (not create_if_not_exists)
+    return NULL;
+
+  user_var_entry *entry= NULL;
+  entry= new (nothrow) user_var_entry(name.c_str(), query_id);
+
+  if (entry == NULL)
+    return NULL;
+
+  std::pair<UserVars::iterator, bool> returnable= user_vars.insert(make_pair(name, entry));
+
+  if (not returnable.second)
   {
-    entry= new (nothrow) user_var_entry(name.c_str(), query_id);
-
-    if (entry == NULL)
-      return NULL;
-
-    std::pair<UserVars::iterator, bool> returnable= user_vars.insert(make_pair(name, entry));
-
-    if (not returnable.second)
-    {
-      delete entry;
-      return NULL;
-    }
+    delete entry;
   }
 
   return entry;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-10-18 17:22:59 +0000
+++ drizzled/session.h	2010-10-19 13:38:53 +0000
@@ -151,22 +151,6 @@
 
 };
 
-struct DrizzleLock
-{
-  Table **table;
-  uint32_t table_count;
-  uint32_t lock_count;
-  THR_LOCK_DATA **locks;
-
-  DrizzleLock() :
-    table(0),
-    table_count(0),
-    lock_count(0),
-    locks(0)
-  { }
-
-};
-
 } /* namespace drizzled */
 
 /** @TODO why is this in the middle of the file */

=== modified file 'drizzled/table/instance.cc'
--- drizzled/table/instance.cc	2010-10-15 05:30:39 +0000
+++ drizzled/table/instance.cc	2010-10-18 02:32:48 +0000
@@ -232,16 +232,21 @@
 {
   uint32_t field_count= getShare()->sizeFields();
 
-  this->def_read_set.resize(field_count);
-  this->def_write_set.resize(field_count);
-  this->tmp_set.resize(field_count);
-  this->getMutableShare()->all_set.resize(field_count);
-  this->getMutableShare()->all_set.set();
-  this->def_write_set.set();
-  this->def_read_set.set();
+  def_read_set.resize(field_count);
+  def_write_set.resize(field_count);
+  tmp_set.resize(field_count);
+  getMutableShare()->all_set.resize(field_count);
+  getMutableShare()->all_set.set();
+  def_write_set.set();
+  def_read_set.set();
   default_column_bitmaps();
 }
 
+Instance::~Instance()
+{
+  free_tmp_table(in_use);
+}
+
 
 } /* namespace table */
 } /* namespace drizzled */

=== modified file 'drizzled/table/instance.h'
--- drizzled/table/instance.h	2010-10-15 05:30:39 +0000
+++ drizzled/table/instance.h	2010-10-18 02:32:48 +0000
@@ -74,10 +74,7 @@
     _has_variable_width= true;
   }
 
-  ~Instance()
-  {
-    free_tmp_table(in_use);
-  }
+  ~Instance();
 };
 
 } /* namespace table */

=== modified file 'drizzled/thr_lock.cc'
--- drizzled/thr_lock.cc	2010-10-10 11:41:42 +0000
+++ drizzled/thr_lock.cc	2010-10-19 04:37:10 +0000
@@ -92,6 +92,8 @@
 
 uint64_t max_write_lock_count= UINT64_MAX;
 
+static void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count);
+
 /*
 ** For the future (now the thread specific cond is alloced by my_pthread.c)
 */
@@ -630,7 +632,7 @@
 
   /* free all locks */
 
-void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count)
+static void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count)
 {
   THR_LOCK_DATA **pos,**end;
 
@@ -642,6 +644,17 @@
   return;
 }
 
+void DrizzleLock::unlock(uint32_t count)
+{
+  THR_LOCK_DATA **pos,**end;
+
+  for (pos= getLocks(),end= getLocks()+count; pos < end ; pos++)
+  {
+    if ((*pos)->type != TL_UNLOCK)
+      thr_unlock(*pos);
+  }
+}
+
 /*
   Abort all threads waiting for a lock. The lock will be upgraded to
   TL_WRITE_ONLY to abort any new accesses to the lock

=== modified file 'drizzled/thr_lock.h'
--- drizzled/thr_lock.h	2010-10-08 16:11:47 +0000
+++ drizzled/thr_lock.h	2010-10-19 04:37:10 +0000
@@ -187,11 +187,9 @@
 
 
 #define thr_lock_owner_init(owner, info_arg) (owner)->info= (info_arg)
-void thr_lock_info_init(THR_LOCK_INFO *info);
 void thr_lock_init(THR_LOCK *lock);
 enum enum_thr_lock_result thr_multi_lock(THR_LOCK_DATA **data,
                                          uint32_t count, THR_LOCK_OWNER *owner);
-void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/util/functors.h'
--- drizzled/util/functors.h	2010-10-14 22:34:11 +0000
+++ drizzled/util/functors.h	2010-10-18 18:24:29 +0000
@@ -34,17 +34,6 @@
   }
 };
 
-class SafeDeletePtr
-{
-public:
-  template<typename T>
-  inline void operator()(const T *ptr) const
-  {
-    if (ptr)
-			delete ptr;
-  }
-};
-
 } /* namespace drizzled */
 
 #endif /* DRIZZLED_UTIL_FUNCTORS_H */

=== removed directory 'mysql-test'
=== renamed file 'mysql-test/innodb_bug46676.result' => 'plugin/innobase/mysql-test/innodb_bug46676.result'
=== renamed file 'mysql-test/innodb_bug46676.test' => 'plugin/innobase/mysql-test/innodb_bug46676.test'
=== modified file 'plugin/innobase/plugin.ini'
--- plugin/innobase/plugin.ini	2010-08-17 20:57:43 +0000
+++ plugin/innobase/plugin.ini	2010-10-19 00:32:30 +0000
@@ -33,6 +33,23 @@
  ChangeLog
  Doxyfile
  README
+ mysql-test/innodb_bug46676.result
+ mysql-test/innodb_bug46676.test
+ mysql-test/innodb-consistent-master.opt
+ mysql-test/innodb-consistent.result
+ mysql-test/innodb-consistent.test
+ mysql-test/innodb_bug44369.result
+ mysql-test/innodb_bug44369.test
+ mysql-test/innodb_bug44571.result
+ mysql-test/innodb_bug44571.test
+ mysql-test/innodb_bug46000.result
+ mysql-test/innodb_bug46000.test
+ mysql-test/innodb_bug47167.result
+ mysql-test/innodb_bug47167.test
+ mysql-test/innodb_bug47777.result
+ mysql-test/innodb_bug47777.test
+ ut/ut0auxconf_have_gcc_atomics.c
+
 
 #cflags=${INNODB_DYNAMIC_CFLAGS} ${NO_SHADOW} -I$(top_srcdir)/storage/innobase/include -DBUILD_DRIZZLE
 #cxxflags=${INNODB_DYNAMIC_CFLAGS} ${NO_SHADOW} -I$(top_srcdir)/storage/innobase/include -DBUILD_DRIZZLE

